@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-1998 Erez Zadok
+ * Copyright (c) 1997-1999 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: transp_tli.c,v 1.1.1.1 1998/11/05 02:04:41 ezk Exp $
+ * $Id: transp_tli.c,v 1.4 1999/08/22 21:12:31 ezk Exp $
  *
  * TLI specific utilities.
  *      -Erez Zadok <ezk@cs.columbia.edu>
@@ -573,7 +573,7 @@ amu_clnt_create_best_vers(const char *hostname, u_long program, u_long *out_vers
   clnt = clnt_create_timed(hostname, program, high_version, nettype, &tv);
   if (!clnt) {
     plog(XLOG_INFO, "failed to create RPC client to \"%s\" after %d seconds",
-	 hostname, tv.tv_sec);
+	 hostname, (int) tv.tv_sec);
     return NULL;
   }
 #else /* not HAVE_CLNT_CREATE_TIMED */
@@ -654,10 +654,10 @@ get_nfs_version(char *host, struct sockaddr_in *sin, u_long nfs_version, const c
 #ifdef DEBUG
   if (nfs_version == NFS_VERSION) {
     dlog("get_nfs_version trying NFS(%d,%s) for %s",
-	 nfs_version, proto, host);
+	 (int) nfs_version, proto, host);
   } else {
     dlog("get_nfs_version trying NFS(%d-%d,%s) for %s",
-	 NFS_VERSION, nfs_version, proto, host);
+	 (int) NFS_VERSION, (int) nfs_version, proto, host);
   }
 #endif /* DEBUG */
   /* get the best NFS version, and timeout quickly if remote host is down */
@@ -667,10 +667,10 @@ get_nfs_version(char *host, struct sockaddr_in *sin, u_long nfs_version, const c
   if (clnt == NULL) {
     if (nfs_version == NFS_VERSION)
       plog(XLOG_INFO, "get_nfs_version NFS(%d,%s) failed for %s %s",
-	   nfs_version, proto, host, clnt_spcreateerror(""));
+	   (int) nfs_version, proto, host, clnt_spcreateerror(""));
     else
       plog(XLOG_INFO, "get_nfs_version NFS(%d-%d,%s) failed for %s %s",
-	   NFS_VERSION, nfs_version, proto, host, clnt_spcreateerror(""));
+	   (int) NFS_VERSION, (int) nfs_version, proto, host, clnt_spcreateerror(""));
     return 0;
   }
   clnt_destroy(clnt);
@@ -768,6 +768,7 @@ create_autofs_service(int *soAUTOFSp, u_short *autofs_portp, SVCXPRT **autofs_xp
     plog(XLOG_ERROR, "Can't create privileged autofs port");
     goto out;
   }
+  (*autofs_xprtp)->xp_port = *autofs_portp;
   if (svc_reg(*autofs_xprtp, AUTOFS_PROG, AUTOFS_VERS, dispatch_fxn, NULL) != 1) {
     plog(XLOG_ERROR, "could not register amd AUTOFS service");
     goto out;
